try:
    from xxhash.cpython import xxh32, xxh64, XXHASH_VERSION
except ImportError:
    from xxhash.cffi import xxh32, xxh64, XXHASH_VERSION


VERSION = '1.0.0'
__all__ = ['xxh32', 'xxh64', 'VERSION', 'XXHASH_VERSION']



import cffi

ffi = cffi.FFI()

ffi.set_source(
    '_cffi',
    '#include "xxhash.h"',
    sources=['c-xxhash/xxhash.c'],
    include_dirs=['c-xxhash']
)

ffi.cdef('''
#define XXH_VERSION_MAJOR ...
#define XXH_VERSION_MINOR ...
#define XXH_VERSION_RELEASE ...

typedef enum { XXH_OK=0, XXH_ERROR } XXH_errorcode;


typedef unsigned int       XXH32_hash_t;

typedef struct XXH32_state_s XXH32_state_t;   /* incomplete type */
 XXH32_state_t* XXH32_createState(void);
 XXH_errorcode  XXH32_freeState(XXH32_state_t* statePtr);
 void XXH32_copyState(XXH32_state_t* restrict dst_state, const XXH32_state_t* restrict src_state);

 XXH_errorcode XXH32_reset  (XXH32_state_t* statePtr, unsigned int seed);
 XXH_errorcode XXH32_update (XXH32_state_t* statePtr, const void* input, size_t length);
 XXH32_hash_t  XXH32_digest (const XXH32_state_t* statePtr);


typedef unsigned long long XXH64_hash_t;

typedef struct XXH64_state_s XXH64_state_t;   /* incomplete type */
 XXH64_state_t* XXH64_createState(void);
 XXH_errorcode  XXH64_freeState(XXH64_state_t* statePtr);
 void XXH64_copyState(XXH64_state_t* restrict dst_state, const XXH64_state_t* restrict src_state);

 XXH_errorcode XXH64_reset  (XXH64_state_t* statePtr, unsigned long long seed);
 XXH_errorcode XXH64_update (XXH64_state_t* statePtr, const void* input, size_t length);
 XXH64_hash_t  XXH64_digest (const XXH64_state_t* statePtr);
''')




if __name__ == '__main__':
    ffi.compile()



import sys
import struct
import binascii

from xxhash._cffi import ffi, lib

PY3 = sys.version_info[0] == 3

XXHASH_VERSION = "%d.%d.%d" % (lib.XXH_VERSION_MAJOR,
                               lib.XXH_VERSION_MINOR,
                               lib.XXH_VERSION_RELEASE)


class xxh32(object):
    digest_size = digestsize = 4
    block_size = 16

    def __init__(self, input=None, seed=0):
        self.xxhash_state = ffi.gc(lib.XXH32_createState(), lib.XXH32_freeState)
        self.seed = seed
        self.reset()
        if input:
            self.update(input)

    def update(self, input):
        if PY3 and isinstance(input, str):
            lib.XXH32_update(self.xxhash_state, input.encode('utf8'), len(input))
        else:
            lib.XXH32_update(self.xxhash_state, input, len(input))

    def intdigest(self):
        return lib.XXH32_digest(self.xxhash_state)

    def digest(self):
        return struct.pack('>I', self.intdigest())

    def hexdigest(self):
        return binascii.hexlify(self.digest())

    def reset(self):
        lib.XXH32_reset(self.xxhash_state, self.seed)

    def copy(self):
        new = type(self)()
        lib.XXH32_copyState(new.xxhash_state, self.xxhash_state)
        new.seed = self.seed
        return new


class xxh64(object):
    digest_size = digestsize = 8
    block_size = 32

    def __init__(self, input=None, seed=0):
        self.xxhash_state = ffi.gc(lib.XXH64_createState(), lib.XXH64_freeState)
        self.seed = seed
        self.reset()
        if input:
            self.update(input)

    def update(self, input):
        if PY3 and isinstance(input, str):
            lib.XXH64_update(self.xxhash_state, input.encode('utf8'), len(input))
        else:
            lib.XXH64_update(self.xxhash_state, input, len(input))

    def intdigest(self):
        return lib.XXH64_digest(self.xxhash_state)

    def digest(self):
        return struct.pack('>Q', self.intdigest())

    def hexdigest(self):
        return binascii.hexlify(self.digest())

    def reset(self):
        lib.XXH64_reset(self.xxhash_state, self.seed)

    def copy(self):
        new = type(self)()
        lib.XXH64_copyState(new.xxhash_state, self.xxhash_state)
        new.seed = self.seed
        return new



#!/usr/bin/env python


from setuptools import setup, Extension
import os

with open('xxhash/__init__.py') as f:
    for line in f:
        if line.startswith('VERSION = '):
            VERSION = eval(line.rsplit(None, 1)[-1])

USE_CPYTHON = os.getenv('XXHASH_FORCE_CFFI') in (None, '0')
setup_kwargs = {}

if os.name == 'posix':
    extra_compile_args = [
        "-std=c99",
        "-O3",
        "-Wall",
        "-W",
        "-Wundef",
        # ref: http://bugs.python.org/issue21121
        "-Wno-error=declaration-after-statement",
    ]
else:
    extra_compile_args = None

if USE_CPYTHON:
    setup_kwargs['ext_modules'] = [
        Extension(
            'cpython',
            ['xxhash/cpython.c', 'c-xxhash/xxhash.c'],
            extra_compile_args=extra_compile_args,
            include_dirs=['c-xxhash']
        )
    ]
else:
    setup_kwargs['install_requires'] = ['cffi']
    setup_kwargs['setup_requires'] = ['cffi']
    setup_kwargs['cffi_modules'] = ['ffibuild.py:ffi']

setup(
    name='xxhash',
    version=VERSION,
    description="Python binding for xxHash",
    long_description=open('README.rst', 'r').read(),
    author='Yue Du',
    author_email='ifduyue@gmail.com',
    url='https://github.com/ifduyue/python-xxhash',
    license='BSD',
    packages=['xxhash'],
    ext_package='xxhash',
    test_suite='nose.collector',
    tests_require=['nose>1.3.0'],
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'License :: OSI Approved :: BSD License',
        'Intended Audience :: Developers',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: Implementation :: CPython',
        'Programming Language :: Python :: Implementation :: PyPy',
    ],
    **setup_kwargs
)
